@@ -7,7 +7,7 @@ from loguru import logger
 from starlette.config import Config
 from starlette.datastructures import CommaSeparatedStrings, Secret
 
-config = Config(".env")
+config = Config("anscenter/.env")
 
 API_PREFIX = "/api"
 VERSION = config("VERSION")
